@@ -7,8 +7,8 @@ from aind_data_schema.ephys.ephys_session import (
     Coordinates3d,
     DAQDevice,
     DomeModule,
-    EphysProbe,
     EphysModule,
+    EphysProbe,
     EphysSession,
     Laser,
     LaserModule,
@@ -58,14 +58,20 @@ stream = Stream(
 )
 
 session = EphysSession(
-    experimenter_full_name="Josh Siegle",
+    experimenter_full_name=["Josh Siegle"],
     subject_id="100001",
     session_start_time=datetime(2023, 1, 10, 8, 40, 00),
     session_end_time=datetime(2023, 1, 10, 9, 46, 00),
     session_type="Test",
     rig_id="323_EPHYS1",
     data_streams=[stream],
-    stick_microscopes=[DomeModule(assembly_name="Stick_assembly", arc_angle=24, module_angle=10,),],
+    stick_microscopes=[
+        DomeModule(
+            assembly_name="Stick_assembly",
+            arc_angle=24,
+            module_angle=10,
+        ),
+    ],
 )
 
 session.write_standard_file()
