@@ -2,12 +2,12 @@
 
 import datetime
 
-from aind_data_schema.subject import Housing, Subject
+from aind_data_schema.subject import Housing, Species, Subject
 
 t = datetime.datetime(2022, 11, 22, 8, 43, 00)
 
 s = Subject(
-    species="Mus musculus",
+    species=Species.MUS_MUSCULUS,
     subject_id="12345",
     sex="Male",
     date_of_birth=t.date(),
