@@ -9,9 +9,8 @@ from typing import List, Optional
 from pydantic import Field
 
 from ..base import AindCoreModel, AindModel
-from ..device import PowerUnit, SizeUnit, AngleUnit
+from ..device import AngleUnit, Coordinates3d, PowerUnit, SizeUnit
 from ..stimulus import StimulusPresentation
-from .ephys_rig import Coordinates3d
 
 
 class SessionType(Enum):
@@ -121,14 +120,15 @@ class Stream(AindModel):
     stimulus_presentations: Optional[List[StimulusPresentation]] = Field(None, title="Stimulus")
     notes: Optional[str] = Field(None, title="Notes")
 
+
 class EphysSession(AindCoreModel):
     """Description of an ephys recording session"""
 
-    schema_version: str = Field("0.4.1", description="schema version", title="Version", const=True)
-    experimenter_full_name: str = Field(
+    schema_version: str = Field("0.4.5", description="schema version", title="Version", const=True)
+    experimenter_full_name: List[str] = Field(
         ...,
-        description="First and last name of the experimenter.",
-        title="Experimenter full name",
+        description="First and last name of the experimenter(s).",
+        title="Experimenter(s) full name",
     )
     session_start_time: datetime = Field(..., title="Session start time")
     session_end_time: datetime = Field(..., title="Session end time")
@@ -138,10 +138,8 @@ class EphysSession(AindCoreModel):
     iacuc_protocol: Optional[str] = Field(None, title="IACUC protocol")
     rig_id: str = Field(..., title="Rig ID")
     stick_microscopes: Optional[List[DomeModule]] = Field(
-        ..., 
-        title="Stick microscopes",
-        description="Must match stick microscope assemblies in rig file"
-        )
+        ..., title="Stick microscopes", description="Must match stick microscope assemblies in rig file"
+    )
     data_streams: List[Stream] = Field(
         ...,
         title="Data streams",
