@@ -9,7 +9,21 @@ from typing import List, Optional, Union
 from pydantic import Field
 
 from ..base import AindCoreModel
-from ..device import CameraAssembly, DataInterface, Device, DAQDevice, Disc, Filter, HarpDevice, Laser, Lens, Monitor, Treadmill, Tube
+from ..device import (
+    CameraAssembly,
+    DAQDevice,
+    DataInterface,
+    Device,
+    Disc,
+    Filter,
+    HarpDevice,
+    Laser,
+    Lens,
+    LightEmittingDiode,
+    Monitor,
+    Treadmill,
+    Tube,
+)
 
 
 class DetectorType(Enum):
@@ -56,7 +70,7 @@ class OphysRig(AindCoreModel):
     """Description of an optical physiology rig"""
 
     schema_version: str = Field(
-        "0.3.6",
+        "0.4.0",
         description="schema version",
         title="Schema Version",
         const=True,
@@ -67,16 +81,14 @@ class OphysRig(AindCoreModel):
     humidity_control: Optional[bool] = Field(None, title="Humidity control")
     vibration_control: Optional[bool] = Field(None, title="Vibration control")
     patch_cords: Optional[List[Patch]] = Field(..., title="Patch cords", unique_items=True)
-    lasers: List[Laser] = Field(..., title="Lasers", unique_items=True)
+    light_sources: List[Union[Laser, LightEmittingDiode]] = Field(..., title="Light sources", unique_items=True)
     detectors: Optional[List[Detector]] = Field(None, title="Detectors", unique_items=True)
     filters: Optional[List[Filter]] = Field(None, title="Filters", unique_items=True)
     lenses: Optional[List[Lens]] = Field(None, title="Lenses", unique_items=True)
     cameras: Optional[List[CameraAssembly]] = Field(None, title="Camera assemblies", unique_items=True)
     mouse_platform: Optional[Union[Tube, Treadmill, Disc]] = Field(None, title="Mouse platform")
     visual_monitors: Optional[List[Monitor]] = Field(None, title="Visual monitors", unique_items=True)
-    daqs: Optional[List[Union[DAQDevice, HarpDevice]]] = Field(
-        None, title="Data acquisition devices"
-    )
+    daqs: Optional[List[Union[DAQDevice, HarpDevice]]] = Field(None, title="Data acquisition devices")
     additional_devices: Optional[List[Device]] = Field(None, title="Additional devices", unique_items=True)
     light_path_diagram: Optional[str] = Field(
         None,
