@@ -1,7 +1,7 @@
 """ testing examples """
 
 import glob
-import importlib
+import importlib.util
 import logging
 import sys
 import unittest
